==> 0.0.1.tar.gz: lib/provider/firebase_doc.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:bmi_global/utils/parsers.dart';

abstract class FirebaseDocProvider<T> with ChangeNotifier {
  T? _doc;
  var _loading = false;
  Object? _error;
  final bool Function(Object error)? cancleOnError;
  final T Function(RawMap data) parse;
  void Function()? _cancle;
  String? _path;

  FirebaseFirestore get firestoreInstance;

  bool get loading => _loading;
  T? get doc => _doc;
  Object? get error => _error;

  FirebaseDocProvider({
    required this.parse,
    this.cancleOnError,
    String? initialPath,
  }) {
    if (initialPath != null) {
      path = initialPath;
    }
  }

  String? get path;
  set path(String? newPath) {
    final oldPath = _path;
    if (oldPath == newPath) return;
    _path = newPath;
    _cancle?.call();
    _doc = null;
    _loading = true;
    _error = null;
    if (newPath != null) {
      _cancle = firestoreInstance
          .doc(newPath)
          .snapshots()
          .handleError(_onError)
          .listen(_listen, cancelOnError: false)
          .cancel;
    } else {
      _cancle = null;
    }
    notifyListeners();
  }

  void _onError(Object error) {
    _loading = false;
    _error = error;
    if (cancleOnError?.call(error) ?? false) {
      _cancle?.call();
      _cancle = null;
    }
  }

  T? convertor(Map<String, Object?>? data) {
    if (data == null) return null;
    return parse(RawObj.toRawMap(data));
  }

  void _listen(DocumentSnapshot<Map<String, Object?>> event) {
    _loading = false;
    _doc = convertor(event.data());
    notifyListeners();
  }

  @override
  void dispose() {
    _cancle?.call();
    super.dispose();
  }
}

==> 0.0.13.tar.gz: lib/provider/firebase_doc.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:bmi_global/utils/parsers.dart';

abstract class FirebaseDocProvider<T> with ChangeNotifier {
  T? _doc;
  var _loading = false;
  Object? _error;
  final bool Function(Object error)? cancleOnError;
  final T Function(RawMap data) parse;
  void Function()? _cancle;
  String? _path;

  FirebaseFirestore get firestoreInstance;

  bool get loading => _loading;
  T? get doc => _doc;
  Object? get error => _error;

  FirebaseDocProvider({
    required this.parse,
    this.cancleOnError,
  }) {
    notifyListeners();
  }

  String? get path;
  @override
  void notifyListeners() {
    final oldPath = _path;
    final newPath = path;
    if (oldPath == newPath) return;
    _path = newPath;
    _cancle?.call();
    _doc = null;
    _loading = true;
    _error = null;
    if (newPath != null) {
      _cancle = firestoreInstance
          .doc(newPath)
          .snapshots()
          .handleError(_onError)
          .listen(_listen, cancelOnError: false)
          .cancel;
    } else {
      _cancle = null;
    }
    super.notifyListeners();
  }

  void _onError(Object error) {
    _loading = false;
    _error = error;
    if (cancleOnError?.call(error) ?? false) {
      _cancle?.call();
      _cancle = null;
    }
  }

  T? convertor(Map<String, Object?>? data) {
    if (data == null) return null;
    return parse(RawMap(data));
  }

  void _listen(DocumentSnapshot<Map<String, Object?>> event) {
    _loading = false;
    _doc = convertor(event.data());
    notifyListeners();
  }

  @override
  void dispose() {
    _cancle?.call();
    super.dispose();
  }
}
